@@ -1,6 +1,5 @@
-#' @docType package
 #' @useDynLib PPRL
 #' @import Rcpp
 #' @importFrom Rcpp evalCpp
 #' @exportPattern "^[[:alpha:]]+"
-NULL
+"_PACKAGE"
