@@ -62,8 +62,8 @@ protected:
   int mCardinality;			// cardinality buffer of CLK
   bool mInP;				// indicator for set P (CanopyCLustering)
   static int sCardinalityMap[0x10000];	// static 16-bit cardinality-map
-  int wLength; 	// length of array of weights for weigthed RLBF
-  vector<int> partsize; 	// vector int for partsizes for weigthed RLBF
+  int wLength; 	// length of array of weights for weighted RLBF
+  vector<int> partsize; 	// vector int for partsizes for weighted RLBF
   int sum = 0;
   int maxPartSize = 0;
   // calculate length of word-array
@@ -396,11 +396,11 @@ public:
   }
 
   // set size of the parts of CLK
-  inline void setPartsize(int lenWeights, float *weigth) {
+  inline void setPartsize(int lenWeights, float *weight) {
     wLength = lenWeights;
     partsize.clear();
     for (int w = 0; w < wLength; w++) {
-      partsize.push_back((int) floor(mLength * weigth[w]));
+      partsize.push_back((int) floor(mLength * weight[w]));
       sum += partsize[w];
     }
     if (sum < mLength) {
