@@ -546,13 +546,13 @@ DataFrame CreateRecordLevelBF(SEXP ID ,DataFrame data, SEXP password, int lenRLB
       varsM.push_back(varsV);
     }
   }
-  if (method != "StaticUniform" &&method != "StaticWeigthed" && method != "DynamicUniform" && method != "DynamicWeigthed"){
-    Rcpp::Rcerr << "'method' can't be '" <<method <<"', it must be eihter 'StaticUniform', 'StaticWeigthed', 'DynamicUniform' or 'DynamicWeigthed'\n";
+  if (method != "StaticUniform" &&method != "StaticWeighted" && method != "DynamicUniform" && method != "DynamicWeighted"){
+    Rcpp::Rcerr << "'method' can't be '" <<method <<"', it must be eihter 'StaticUniform', 'StaticWeighted', 'DynamicUniform' or 'DynamicWeighted'\n";
     delete rlbf;
     delete[] CLKout;
     return RLBFout;
   }
-  if (method == "StaticWeigthed"||method == "DynamicWeigthed"){ // set length of the parts of the rlbf if it is weigthed
+  if (method == "StaticWeighted"||method == "DynamicWeighted"){ // set length of the parts of the rlbf if it is weighted
     if ((unsigned)weigths_.size() != data.size()){
       Rcpp::Rcerr << "Vector weights must have the same size as the input data.frame.";
       delete rlbf;
@@ -569,7 +569,7 @@ DataFrame CreateRecordLevelBF(SEXP ID ,DataFrame data, SEXP password, int lenRLB
     //set sizes of the parts
     rlbf ->setPartsize(data.size(), &weigths_[0]);
 
-  } else{ // set length of the parts of the rlbf if it is not weigthed
+  } else{ // set length of the parts of the rlbf if it is not weighted
     weigths_.clear();
     for (int i  = 0 ; i<data.size(); i++){
       if (data.size()>0){
@@ -579,7 +579,7 @@ DataFrame CreateRecordLevelBF(SEXP ID ,DataFrame data, SEXP password, int lenRLB
     rlbf ->setPartsize(data.size(), &weigths_[0]);
   }
 
-  if (method == "StaticUniform"||method == "StaticWeigthed"){ // set length of Bloom Filter if "Static"
+  if (method == "StaticUniform"||method == "StaticWeighted"){ // set length of Bloom Filter if "Static"
     if (lenBloom.size()>1){
       Rcpp::Rcerr << "Length of the vector of length of Bloom filters is bigger than 1, all BF have to have the same size, the first value will be taken.";
     }
